@@ -128,7 +128,7 @@ class MyWhatify:
     @classmethod
     def run_prediction(cls, data_name, ensemble_id, data_file=None, wait=True, file_path=None, header=None, data_id=None):
         with allure.step('running prediction on data name: ' + data_name + ' with ensemble id: ' + str(ensemble_id) + ' and wait is: ' + str(wait)):
-            print('running the prediction on data name: ' + data_name + ' with ensemble id: ' + str(ensemble_id) + ' and wait is: ' + str(wait))
+            print('running prediction on data name: ' + data_name + ' with ensemble id: ' + str(ensemble_id) + ' and wait is: ' + str(wait))
             logging.info('running prediction on data name: ' + data_name + ' with ensemble id: ' + str(ensemble_id) + ' and wait is: ' + str(wait))
             status = True
             predict_id = None
